dataform library

Classes

DataForm
A widget that manages a Map of data that will be used to store the data of the form fields.
DataFormCheckbox
A widget that displays a checkbox with a text and a description
DataFormField<T>
Wrap your form fields with this widget to specify its ids and optionally a formatter. This widget must be a descendant of a DataForm widget.
DataFormState
Use DataFormState.maybeOf or DataFormState.of to get the state of current DataForm. With this state you can call fetchData to get the form data as a Map<String, dynamic> or saveField to save a value in the form data.
DataFormSwitch
A widget that displays a switch with a text and a description
DataFormTextField<T>
A TextField that can be used inside a DataForm to save its value in a Map<String, dynamic>.+

Enums

CheckboxPosition
Specifies the position of the checkbox in the DataFormCheckbox widget
SwitchPosition
Specifies the position of the switch in the DataFormSwitch widget